@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import (Any, Dict, List, NoReturn, Sequence, Tuple, Type, Union, Optional)
+from typing import Any, Dict, List, NoReturn, Sequence, Tuple, Type, Union, Optional
 
 from graia.application.exceptions import EntangledSuperposition
 from graia.broadcast.utilles import run_always_await
@@ -13,9 +13,11 @@ import copy
 T = Element
 MessageIndex = Tuple[int, Optional[int]]
 
+
 def raiser(error):
     raise error
 
+
 class MessageChain(BaseModel):
     """即 "消息链", 被用于承载整个消息内容的数据结构, 包含有一有序列表, 包含有继承了 Element 的各式类实例.
 
@@ -47,7 +49,7 @@ class MessageChain(BaseModel):
             # 使用 in 运算符也可以
             print(At in message)
             ```
-    
+
         7. 可以使用 `MessageChain.get` 方法获取消息链中的所有特定类型的元素:
 
             ``` python
@@ -72,9 +74,9 @@ class MessageChain(BaseModel):
             ) # -> MessageChain
             ```
         10. `MessageChain.plusWith` 方法将在现有的基础上将另一消息链拼接到原来实例的尾部, 并生成, 返回新的实例; 该方法不改变原有和传入的实例.
-        
+
         11. `MessageChain.plus` 方法将在现有的基础上将另一消息链拼接到原来实例的尾部; 该方法更改了原有的实例, 并要求 `isMutable` 方法返回 `True` 才可以执行.
-        
+
         12. `MessageChain.asSerializationString` 方法可将消息链对象转为以 "Mirai 码" 表示特殊对象的字符串
 
         13. `MessageChain.fromSerializationString` 方法可以从以 "Mirai 码" 表示特殊对象的字符串解析为消息链, 不过可能不完整.
@@ -82,7 +84,7 @@ class MessageChain(BaseModel):
         14. `MessageChain.asMerged` 方法可以将消息链中相邻的 Plain 元素合并为一个 Plain 元素.
 
         15. 你可以通过一个分片实例取项, 这个分片的 `start` 和 `end` 的 Type Annotation 都是 `Optional[MessageIndex]`:
-        
+
             ``` python
             message = MessageChain.create([
                 Plain("123456789"), At(123), Plain("3423")
@@ -90,6 +92,7 @@ class MessageChain(BaseModel):
             message.asMerged()[(0, 12):] # => [At(123), Plain("3423")]
             ```
     """
+
     __root__: Union[List[T], Tuple[T]]
 
     @classmethod
@@ -105,7 +108,7 @@ class MessageChain(BaseModel):
         return cls(__root__=elements)
 
     @classmethod
-    def parse_obj(cls: Type['MessageChain'], obj: List[T]) -> 'MessageChain':
+    def parse_obj(cls: Type["MessageChain"], obj: List[T]) -> "MessageChain":
         """内部接口, 会自动将作为外部态的消息元素转为内部态.
 
         Args:
@@ -124,18 +127,20 @@ class MessageChain(BaseModel):
                         handled_elements.append(ii.fromExternal(i))
             elif isinstance(i, dict) and "type" in i:
                 for ii in ExternalElement.__subclasses__():
-                    if ii.__name__ == i['type']:
+                    if ii.__name__ == i["type"]:
                         for iii in InternalElement.__subclasses__():
-                            if iii.__name__ == i['type']:
-                                handled_elements.append(iii.fromExternal(ii.parse_obj(i)))
-        return cls(__root__=tuple(handled_elements)) # 默认是不可变型
+                            if iii.__name__ == i["type"]:
+                                handled_elements.append(
+                                    iii.fromExternal(ii.parse_obj(i))
+                                )
+        return cls(__root__=tuple(handled_elements))  # 默认是不可变型
 
     @property
     def isImmutable(self) -> bool:
         """判断消息链是否不可变
 
         Returns:
-            bool: 判断结果, `True` 为不可变, `False` 为可变 
+            bool: 判断结果, `True` 为不可变, `False` 为可变
         """
         return isinstance(self.__root__, tuple)
 
@@ -162,11 +167,16 @@ class MessageChain(BaseModel):
         Returns:
             bool: 判断的结果, True 为可发送, False 则反之.
         """
-        return all(all([
-            isinstance(i, (InternalElement, ExternalElement)),
-            hasattr(i, "toExternal"),
-            getattr(i.__class__, "toExternal") != InternalElement.toExternal
-        ]) for i in self.__root__)
+        return all(
+            all(
+                [
+                    isinstance(i, (InternalElement, ExternalElement)),
+                    hasattr(i, "toExternal"),
+                    getattr(i.__class__, "toExternal") != InternalElement.toExternal,
+                ]
+            )
+            for i in self.__root__
+        )
 
     def asSendable(self) -> "MessageChain":
         """将消息链尽量转换为能够为发送消息的方法正确发送的新消息链, 该方法不保证转换无误差性, 且不保证转化后是否可以被发送.
@@ -174,22 +184,43 @@ class MessageChain(BaseModel):
         Returns:
             MessageChain: 返回的可能可以正确发送的消息链.
         """
-        return MessageChain(__root__=tuple([i for i in self.__root__ if all([
-            isinstance(i, InternalElement),
-            hasattr(i, "toExternal"),
-            getattr(i.__class__, "toExternal") != InternalElement.toExternal
-        ])]))
+        return MessageChain(
+            __root__=tuple(
+                [
+                    i
+                    for i in self.__root__
+                    if all(
+                        [
+                            isinstance(i, InternalElement),
+                            hasattr(i, "toExternal"),
+                            getattr(i.__class__, "toExternal")
+                            != InternalElement.toExternal,
+                        ]
+                    )
+                ]
+            )
+        )
 
-    async def build(self, **extra: Dict[InternalElement, Tuple[list, dict]]) -> "MessageChain":
+    async def build(
+        self, **extra: Dict[InternalElement, Tuple[list, dict]]
+    ) -> "MessageChain":
         result = []
         for i in self.__root__:
             if isinstance(i, InternalElement):
                 if getattr(i.__class__, "toExternal") == InternalElement.toExternal:
-                    raise EntangledSuperposition("You define an object that cannot be sent: {0}".format(i.__class__.__name__))
-                result.append(await run_always_await(i.toExternal(
-                    *(extra[i.__class__][0] if i.__class__ in extra else []),
-                    **(extra[i.__class__][1] if i.__class__ in extra else {})
-                )))
+                    raise EntangledSuperposition(
+                        "You define an object that cannot be sent: {0}".format(
+                            i.__class__.__name__
+                        )
+                    )
+                result.append(
+                    await run_always_await(
+                        i.toExternal(
+                            *(extra[i.__class__][0] if i.__class__ in extra else []),
+                            **(extra[i.__class__][1] if i.__class__ in extra else {})
+                        )
+                    )
+                )
             else:
                 result.append(i)
         return MessageChain(__root__=tuple(result))
@@ -263,7 +294,9 @@ class MessageChain(BaseModel):
         elif issubclass(item, Element):
             return self.get(item)
         else:
-            raise NotImplementedError("{0} is not allowed for item getting".format(type(item)))
+            raise NotImplementedError(
+                "{0} is not allowed for item getting".format(type(item))
+            )
 
     def subchain(self, item: slice) -> "MessageChain":
         """对消息链执行分片操作
@@ -278,28 +311,37 @@ class MessageChain(BaseModel):
             MessageChain: 分片后得到的新消息链, 绝对是原消息链的子集.
         """
         from .elements.internal import Plain
+
         result = copy.copy(self.__root__)
         if item.start:
-            first_slice = result[item.start[0]:]
-            if item.start[1] is not None and first_slice: # text slice
+            first_slice = result[item.start[0] :]
+            if item.start[1] is not None and first_slice:  # text slice
                 if not isinstance(first_slice[0], Plain):
-                    raise TypeError("the sliced chain does not starts with a Plain: {}".format(first_slice[0]))
-                final_text = first_slice[0].text[item.start[1]:]
+                    raise TypeError(
+                        "the sliced chain does not starts with a Plain: {}".format(
+                            first_slice[0]
+                        )
+                    )
+                final_text = first_slice[0].text[item.start[1] :]
                 result = [
                     *([Plain(final_text)] if final_text else []),
-                    *first_slice[1:]
+                    *first_slice[1:],
                 ]
             else:
                 result = first_slice
         if item.stop:
-            first_slice = result[:item.stop[0]]
-            if item.stop[1] is not None and first_slice: # text slice
+            first_slice = result[: item.stop[0]]
+            if item.stop[1] is not None and first_slice:  # text slice
                 if not isinstance(first_slice[-1], Plain):
-                    raise TypeError("the sliced chain does not ends with a Plain: {}".format(first_slice[-1]))
-                final_text = first_slice[-1].text[:item.stop[1]]
+                    raise TypeError(
+                        "the sliced chain does not ends with a Plain: {}".format(
+                            first_slice[-1]
+                        )
+                    )
+                final_text = first_slice[-1].text[: item.stop[1]]
                 result = [
                     *first_slice[:-1],
-                    *([Plain(final_text)] if final_text else [])
+                    *([Plain(final_text)] if final_text else []),
                 ]
             else:
                 result = first_slice
@@ -312,16 +354,15 @@ class MessageChain(BaseModel):
             str: 以 "Mirai 码" 表示特殊对象的字符串
         """
         from .elements.internal import Plain
+
         result = []
         for e in self.__root__:
             if isinstance(e, Plain):
-                result.append(e.asSerializationString().replace('[', '[_'))
+                result.append(e.asSerializationString().replace("[", "[_"))
             else:
                 result.append(e.asSerializationString())
-        return ''.join(result)
-    
-    
-    
+        return "".join(result)
+
     @classmethod
     def fromSerializationString(cls, string: str) -> "MessageChain":
         """将以 "Mirai 码" 表示特殊对象的字符串转为消息链对象
@@ -330,33 +371,34 @@ class MessageChain(BaseModel):
             MessageChain: 转换后得到的消息链, 所包含的信息可能不完整.
         """
         from .elements.internal import Plain, At, AtAll, Source, FlashImage, Image, Face
+
         PARSE_FUNCTIONS = {
-            'atall': lambda args: AtAll(),
-            'source': lambda args: Source(id=args[0], time=args[1]),
-            'at': lambda args: At(target=args[0], display=args[1]),
-            'face': lambda args: Face(faceId=args[0]),
-            'image': lambda args: Image(imageId=args[0]),
-            'flash': lambda args: FlashImage(imageId=args[0]),
+            "atall": lambda args: AtAll(),
+            "source": lambda args: Source(id=args[0], time=args[1]),
+            "at": lambda args: At(target=args[0], display=args[1]),
+            "face": lambda args: Face(faceId=args[0]),
+            "image": lambda args: Image(imageId=args[0]),
+            "flash": lambda args: FlashImage(imageId=args[0]),
         }
         result = []
-        for match in regex.split(r'(\[mirai:.+?\])', string):
-            mirai = regex.fullmatch(r'\[mirai:(.+?)(:(.+?))\]', match)
+        for match in regex.split(r"(\[mirai:.+?\])", string):
+            mirai = regex.fullmatch(r"\[mirai:(.+?)(:(.+?))\]", match)
             if mirai:
                 # 容错：参数数量太少不行，太多可以
-                args = mirai.group(3).split(',')
+                args = mirai.group(3).split(",")
                 result.append(PARSE_FUNCTIONS[mirai.group(1)](args))
             elif match:
-                result.append(Plain(match.replace('[_', '[')))
+                result.append(Plain(match.replace("[_", "[")))
         return MessageChain.create(result)
 
-
     def asMerged(self) -> "MessageChain":
         """合并相邻的 Plain 项, 并返回一个新的消息链实例
-        
+
         Returns:
             MessageChain: 得到的新的消息链实例, 里面不应存在有任何的相邻的 Plain 元素.
         """
         from .elements.internal import Plain
+
         result = []
 
         plain = []
@@ -364,16 +406,16 @@ class MessageChain(BaseModel):
             if not isinstance(i, Plain):
                 if plain:
                     result.append(Plain("".join(plain)))
-                    plain.clear() # 清空缓存
+                    plain.clear()  # 清空缓存
                 result.append(i)
             else:
                 plain.append(i.text)
         else:
             if plain:
                 result.append(Plain("".join(plain)))
-                plain.clear() # 清空缓存
-        return MessageChain.create(type(self.__root__)(result)) # 维持 Mutable
-    
+                plain.clear()  # 清空缓存
+        return MessageChain.create(type(self.__root__)(result))  # 维持 Mutable
+
     def exclude(self, *types: Type[Element]) -> MessageChain:
         """将除了在给出的消息元素类型中符合的消息元素重新包装为一个新的消息链
 
@@ -383,10 +425,10 @@ class MessageChain(BaseModel):
         Returns:
             MessageChain: 返回的消息链中不包含参数中给出的消息元素类型
         """
-        return self.create(type(self.__root__)([
-            i for i in self.__root__ if type(i) not in types
-        ]))
-    
+        return self.create(
+            type(self.__root__)([i for i in self.__root__ if type(i) not in types])
+        )
+
     def include(self, *types: Type[Element]) -> MessageChain:
         """将只在给出的消息元素类型中符合的消息元素重新包装为一个新的消息链
 
@@ -396,10 +438,10 @@ class MessageChain(BaseModel):
         Returns:
             MessageChain: 返回的消息链中只包含参数中给出的消息元素类型
         """
-        return self.create(type(self.__root__)([
-            i for i in self.__root__ if type(i) in types
-        ]))
-    
+        return self.create(
+            type(self.__root__)([i for i in self.__root__ if type(i) in types])
+        )
+
     def split(self, pattern: str) -> List["MessageChain"]:
         """和 `str.split` 差不多, 提供一个字符串, 然后返回分割结果.
 
@@ -407,6 +449,7 @@ class MessageChain(BaseModel):
             List["MessageChain"]: 分割结果, 行为和 `str.split` 差不多.
         """
         from .elements.internal import Plain
+
         result: List["MessageChain"] = []
         tmp = []
         for element in self.__root__:
@@ -425,9 +468,17 @@ class MessageChain(BaseModel):
                 result.append(MessageChain.create(tmp))
                 tmp = []
         return result
-    
+
     def asHypertext(self) -> "MessageChain":
-        from graia.application.message.elements.internal import Source, Quote, Xml, Json, App, Poke
+        from graia.application.message.elements.internal import (
+            Source,
+            Quote,
+            Xml,
+            Json,
+            App,
+            Poke,
+        )
+
         """将消息链转换为**不包含以下消息元素**的消息链:
 
          - `Source`
